==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","");
define("_RE","Re");
define("_SUBJECT","ͧ");
define("_PRIVATEMESSAGES","Your Private Messages");
define("_CHECKALL","Check All");
define("_FROM","");
define("_DATE","ѹ");
define("_DONTHAVEMESSAGES","سբͤ");
define("_NOTREAD","ѧҹ");
define("_MSGSTATUS","ʶҹТͧͤ");
define("_PRIVATEMESSAGE","ͤǹ");
define("_INDEX","Ѫ");
define("_SENT","");
define("_PREVIOUSMESSAGE","ͤ͹˹ҹ");
define("_NEXTMESSAGE","ͤѴ");
define("_PROFILE","ѵ");
define("_ABOUTPOSTING","˵");
define("_ALLREGCANPOST","к觢ͤǹҧҪԡҹ");
define("_TO","֧");
define("_MESSAGEICON","ͤҾ");
define("_MESSAGE","ͤ");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","¹");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","ЧѺ HTML 㹡觢ͤ ");
define("_BBCODEDISSABLE","кЧѺ <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a㹡觢ͤ");
define("_SMILEDISSABLE","кЧѺ <a href=\"bb_smilies.php\" target=\"_blank\"><i>ͤҾ</i></a> 㹡觢ͤ");
define("_CANCELREPLY","¡ԡ õͺѺ");
define("_CANCELSEND","¡ԡ ");
define("_CLEAR","ź˹Ҩ");
define("_SUBMIT","");
define("_USERNOTINDB","ҹ͡㹰ҹҪԡ()");
define("_CHECKNAMEANDTRY","ôǨͺ .");
define("_MSGPOSTED","ͤͧҹ١͡");
define("_RETURNTOPMSG","سҡ¡ͤǹǢ");
define("_MSGDELETED","ͤͧҹ١ź");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","");
define("_RE","Re");
define("_SUBJECT","ͧ");
define("_PRIVATEMESSAGES","Your Private Messages");
define("_CHECKALL","Check All");
define("_FROM","");
define("_DATE","ѹ");
define("_DONTHAVEMESSAGES","سբͤ");
define("_NOTREAD","ѧҹ");
define("_MSGSTATUS","ʶҹТͧͤ");
define("_PRIVATEMESSAGE","ͤǹ");
define("_INDEX","Ѫ");
define("_SENT","");
define("_PREVIOUSMESSAGE","ͤ͹˹ҹ");
define("_NEXTMESSAGE","ͤѴ");
define("_PROFILE","ѵ");
define("_ABOUTPOSTING","˵");
define("_ALLREGCANPOST","к觢ͤǹҧҪԡҹ");
define("_TO","֧");
define("_MESSAGEICON","ͤҾ");
define("_MESSAGE","ͤ");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","¹");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","ЧѺ HTML 㹡觢ͤ ");
define("_BBCODEDISSABLE","кЧѺ <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a㹡觢ͤ");
define("_SMILEDISSABLE","кЧѺ <a href=\"bb_smilies.php\" target=\"_blank\"><i>ͤҾ</i></a> 㹡觢ͤ");
define("_CANCELREPLY","¡ԡ õͺѺ");
define("_CANCELSEND","¡ԡ ");
define("_CLEAR","ź˹Ҩ");
define("_SUBMIT","");
define("_USERNOTINDB","ҹ͡㹰ҹҪԡ()");
define("_CHECKNAMEANDTRY","ôǨͺ .");
define("_MSGPOSTED","ͤͧҹ١͡");
define("_RETURNTOPMSG","سҡ¡ͤǹǢ");
define("_MSGDELETED","ͤͧҹ١ź");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
